@@ -2,9 +2,10 @@ package Net::CIDR::MobileJP;
 use strict;
 use warnings;
 use Carp;
-use version; our $VERSION = qv('0.0.2');
 use YAML;
 use Net::CIDR::Lite;
+use File::ShareDir ();
+our $VERSION = '0.0.9';
 
 sub new {
     my ($class, $stuff) = @_;
@@ -32,12 +33,15 @@ sub _load_config {
     my ($self, $stuff) = @_;
 
     my $data;
-    if (-f $stuff && -r _) {
+    if (defined $stuff && -f $stuff && -r _) {
         # load yaml from file
         $data = YAML::LoadFile($stuff);
-    } else {
+    } elsif ($stuff) {
         # raw data
         $data = $stuff;
+    } else {
+        # generated file
+        $data = YAML::LoadFile(File::ShareDir::module_file('Net::CIDR::MobileJP', 'cidr.yaml'));
     }
     return $data;
 }
@@ -95,6 +99,8 @@ Carrier name is compatible with L<HTTP::MobileAgent>.
 =head1 THANKS TO
 
   Tatsuhiko Miyagawa
+  Masayoshi Sekimura
+  HIROSE, Masaaki
 
 =head1 SEE ALSO
 
